import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import theme from '../components/theme'

const parseBackground = (val, interactive) => {
  if (theme.backgrounds.hasOwnProperty(val)) {
    const bg = theme.backgrounds[val]
    console.log(bg)
    return css({
      color: bg.textColor,
      backgroundColor: bg.backgroundColor,
      borderColor: bg.borderColor,
      ...(interactive ? {
        '&:hover, &:active': {
          borderColor: `${bg.borderColorInteractive} !impotant`
        }
      } : {})
    })
  }
}

const parseProps = ({ background, interactive, className, ...props }) => ({
  className: background !== undefined ? cx(`${parseBackground(background, interactive)}`, className) : className,
  ...props
})

const withBackground = (Comp) => {
  const BackgroundComp = (props) =>
    React.createElement(Comp, parseProps(props))

  BackgroundComp.propTypes = {
    ...Comp.propTypes,
    background: PropTypes.oneOf(Object.keys(theme.backgrounds)),
    interactive: PropTypes.bool
  }

  BackgroundComp.displayName = Comp.displayName

  return BackgroundComp
}

export {
  withBackground
}
