import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import theme from '../components/theme'

const parseShadow = (val) => {
  const i = Number.isInteger(val) ? val - 1 : 0
  return css({
    boxShadow: theme.shadows[i]
  })
}

const parseProps = ({ shadow, className, ...props }) => ({
  className: shadow !== undefined ? cx(`${parseShadow(shadow)}`, className) : className,
  ...props
})

const withShadow = (Comp) => {
  const ShadowComp = (props) =>
    React.createElement(Comp, parseProps(props))

  ShadowComp.propTypes = {
    ...Comp.propTypes,
    shadow: PropTypes.oneOfType([
      PropTypes.bool,
      PropTypes.oneOf(theme.shadows.map((_, i) => i))
    ])
  }

  ShadowComp.displayName = Comp.displayName

  return ShadowComp
}

export {
  withShadow
}
